@@ -359,10 +359,3 @@ instance Ord k => A.FiniteMap (FM k) k where
    intersectionWithKey = intersectionWithKey}
 
 instance Ord k => A.OrdFiniteMap (FM k) k
-
-instance (Ord k,Arbitrary k,Arbitrary a) => Arbitrary (FM k a) where
-   arbitrary = do (xs::[(k,a)]) <- arbitrary
-                  return (Prelude.foldr (uncurry insert) empty xs)
-
-instance (Ord k,CoArbitrary k,CoArbitrary a) => CoArbitrary (FM k a) where
-   coarbitrary mp = coarbitrary (A.toList mp)
