@@ -53,6 +53,8 @@ import Prelude hiding (concat,reverse,map,concatMap,foldr,foldl,foldr1,foldl1,
                        zip,zip3,zipWith,zipWith3,unzip,unzip3,null)
 
 import qualified Data.Edison.Seq as S ( Sequence(..) )
+import qualified Control.Applicative as App
+
 import Data.Edison.Seq.Defaults
 import Control.Monad
 import Data.Monoid
@@ -387,6 +389,17 @@ instance S.Sequence Seq where
 instance Functor Seq where
   fmap = map
 
+instance App.Alternative Seq where
+  empty = empty
+  (<|>) = append
+
+instance App.Applicative Seq where
+  pure = return
+  x <*> y = do
+     x' <- x
+     y' <- y
+     return (x' y')
+
 instance Monad Seq where
   return = singleton
   xs >>= k = concatMap k xs
